import arrayTiTi.ArrayIO;

import imageTiTi.ImageIO;
import imageTiTi.reducer.ColorReducer;
import imageTiTi.reducer.GrayLevelReducer;

import java.awt.image.BufferedImage;
import java.io.IOException;

import measures.rasemotte.Distance;
import measures.rasemotte.DistanceTools;

import patternRecognition.textures.glzm.glolzm.MGlolzm;
import patternRecognition.textures.glzm.glszm.GlszmFeatures;
import patternRecognition.textures.glzm.glszm.MGlszm;



public class ThibaultMatrices
{


public static void main(String[] args) throws IOException
	{
	BufferedImage imdna = ImageIO.Read("Images/DNA.png") ;
	
	int nbGrayLevel = 32 ; // the number of gray level after reduction. After reduction of gray level, the matrix is more robust to noise.
	int nbSizes = 5 ; // coefficient to reduce the size zone. If it is equal to 1, any reduction is done. This reduction reduces the matrix width and improves slightly performances because zones with close sizes are now in the same case.
	boolean FixedSize = false ; // variable to know if the matrix must have a fixed size. Empirically, I have never obtained better results with a fixed size, so my advice is to always use this parameter as false.
	ColorReducer reducer = new GrayLevelReducer() ; // reduces the number of gray level.
	int ForbiddenValue = 0 ; // The value to not take into account during computations. If it is equal to a negative value, the entire texture is process.
	boolean EightConnex = true ; // Is the labeling realized with 8-connexity?
	int nbCPU = 1 ; // the number of thread to use for processing.
	
	GlszmFeatures glszm = new GlszmFeatures() ;
	glszm.Parameters(nbGrayLevel, nbSizes, FixedSize, reducer, null, ForbiddenValue, EightConnex, nbCPU) ; // Set parameters
	glszm.Compute(imdna, nbCPU) ; // Fills matrix and computes features.
	
	System.out.println("\nSize Zone Matrix") ;
	ArrayIO.Display(glszm.FeaturesNames(), " ") ; // Displays features names.
	ArrayIO.Display(glszm.Features(), " ") ; // Displays features.
	
	
	
	MGlszm mglszm = new MGlszm() ;
	mglszm.Parameters(nbSizes, FixedSize, reducer, null, ForbiddenValue, EightConnex) ;  // Set parameters
	mglszm.Compute(imdna, nbCPU) ;
	System.out.println("\nMultiple Gray Level Size Zone Matrix") ;
	ArrayIO.Display(mglszm.FeaturesNames(), " ") ; // Displays features names.
	ArrayIO.Display(mglszm.Features(), " ") ; // Displays features.
	
	
	
	BufferedImage immic = ImageIO.Read("Images/Microtubules.png") ;
	
	int nbLength = 1 ; // the number of length to take into account.
	int nbOrientation = 90 ; // Number of orientation to take into account.
	boolean UseAverageOrientation = true ; // Use the average orientation in order to compute the orientation of each zone? If true, so the matrix is rotation invariant.
	boolean UseGapToAO = true ; // Fill the matrix with the gap to the average orientation?
	Distance distance = DistanceTools.CreateMontanariDistance(2, 3) ; // The distance to use for the computation of the diameter. 2 is the dimension and 3 the radius
	
	MGlolzm mglolzm = new MGlolzm() ;
	mglolzm.Parameters(nbLength, nbOrientation, FixedSize, UseAverageOrientation, UseGapToAO, reducer, null, ForbiddenValue, EightConnex, distance) ;
	mglolzm.Compute(immic, nbCPU) ;
	
	System.out.println("\nMultiple Gray Level Orientation and Length Zone Matrix") ;
	ArrayIO.Display(mglolzm.FeaturesNames(), " ") ; // Displays features names.
	ArrayIO.Display(mglolzm.Features(), " ") ; // Displays features.
	}
	
}
